@@ -98,6 +98,14 @@ class SurfingEntrance(object):
         FOFBase.metadata.create_all(bind=TestDatabaseConnector().get_engine())
         print('done')
 
+    def init_TL(self):
+        from .data.wrapper.mysql import TLDatabaseConnector
+        from .data.view.TL_models import Base
+
+        print('Begin to create tables for database: test')
+        Base.metadata.create_all(bind=TLDatabaseConnector().get_engine())
+        print('done')
+
     def init_cas(self):
         from .data.wrapper.cas.cas_init import sync_cas_table
 
