@@ -1099,7 +1099,7 @@ class DerivedDataApi(metaclass=Singleton):
             print(f'failed to get data <err_msg> {e} from derived.get_style_factor_ret')
             return False
 
-    def get_industry_stock_ret_and_size(self, begin_date, end_date, time_para):
+    def get_industry_stock_ret_and_size(self, begin_date, end_date, time_para, index_id='all_a'):
         try:
             def process_x(x):
                 x.loc[:,'weight'] = x['size'] / x['size'].sum()
@@ -1114,7 +1114,11 @@ class DerivedDataApi(metaclass=Singleton):
             stock_df = raw_api.get_em_stock_info()
             industry_df = raw_api.get_em_industry_info()
             stock_df = stock_df[stock_df.list_date < _b_d]
-            stock_list = stock_df.stock_id.to_list()
+            if index_id == 'all_a':
+                stock_list = stock_df.stock_id.to_list()
+            else:
+                df = raw_api.get_em_index_component(index_list=[index_id])
+                stock_list = df.stock_list.dropna().iloc[-1].split(',')
             total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'])
             stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,stock_list=stock_list,columns=['close'])
 
@@ -1254,6 +1258,80 @@ class DerivedDataApi(metaclass=Singleton):
         }
         return data
 
+    def get_industry_stock_ret_and_size_v2(index_id, begin_date, end_date, time_para):
+        try:
+            def process_x(x):
+                x.loc[:,'weight'] = x['size'] / x['size'].sum()
+                x = x[x.weight >= 0.03]
+                return x
+            # load data
+            today = datetime.date.today()
+            _b_d = today - datetime.timedelta(days=90)
+            raw_api = RawDataApi()
+            basic_api = BasicDataApi()
+            begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
+            df = raw_api.get_em_index_component(index_list=index_id)
+            stock_list1 = df.stock_list.dropna()[0].split(',')
+            stock_df = raw_api.get_em_stock_info(stock_list1)
+            industry_df = raw_api.get_em_industry_info()
+            stock_df = stock_df[stock_df.list_date < _b_d]
+            stock_list = stock_df.stock_id.to_list()
+            total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'] )
+            stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,
+                                                        stock_list=stock_list,columns=['close'])
+
+            # data_clean
+            industry_dic_name = industry_df.set_index('em_id').to_dict()['ind_name']
+            stock_df = stock_df[['stock_id','name','bl_sws_ind_code']].dropna()
+            stock_df.loc[:,'industry_1'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[0])
+            stock_df.loc[:,'industry_2'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[1])
+            stock_df = stock_df.drop(columns=['bl_sws_ind_code']).set_index('stock_id')
+            stock_df.loc[:,'industry_1_name'] = stock_df.industry_1.map(industry_dic_name)
+            stock_df.loc[:,'industry_2_name'] = stock_df.industry_2.map(industry_dic_name)
+            total_share = total_share.pivot_table(index='stock_id',columns='datetime',values='total_share')
+            total_share.columns = ['total_share']
+            last_date = sorted(stock_price.datetime.unique().tolist())[-1]
+            last_price = stock_price[stock_price['datetime'] == last_date]
+            size_df = last_price.set_index('stock_id')[['close']].join(total_share).dropna()
+            size_df.loc[:,'size'] = size_df.close*size_df.total_share
+            stock_df = stock_df.join(size_df).copy()
+            stock_df = stock_df.groupby('industry_2').apply(lambda x: process_x(x))
+            stock_df = stock_df.drop(columns=['industry_2']).reset_index().set_index('stock_id')
+
+            indus_size_1 = stock_df[['industry_1','size']].groupby('industry_1').sum()
+            indus_size_2 = stock_df[['industry_2','size']].groupby('industry_2').sum()
+            stock_price = stock_price.pivot_table(index='datetime',columns='stock_id',values='close').ffill()
+            stock_ret = pd.DataFrame(stock_price.iloc[-1] / stock_price.iloc[0] - 1)
+            stock_ret.columns=['stock_ret']
+            stock_df = stock_df.join(stock_ret).dropna()
+            industry_list = indus_size_1.index.tolist() + indus_size_2.index.tolist()
+            index_info = basic_api.get_index_info_by_em_id(em_id_list=industry_list)
+            industry_dic = index_info.set_index('index_id').to_dict()['em_id']
+            index_list = list(industry_dic.keys())
+            industry_price = basic_api.get_index_price_dt(start_date=begin_date,end_date=end_date,
+                                                            index_list=index_list,columns=[IndexPrice.close])
+            industry_price = industry_price.pivot_table(columns='index_id',values='close',index='datetime').ffill()
+            industry_price = industry_price.rename(columns=industry_dic)
+            indus_ret = pd.DataFrame(industry_price.iloc[-1] / industry_price.iloc[0] - 1)
+            indus_ret.columns= ['industry_ret']
+            indus_size_1 = indus_size_1.join(indus_ret).dropna()
+            indus_size_2 = indus_size_2.join(indus_ret).dropna()
+            indus_size_1.loc[:,'industry_1_name'] = indus_size_1.index.map(industry_dic_name)
+            indus_size_2.loc[:,'industry_2_name'] = indus_size_2.index.map(industry_dic_name)
+            _df = stock_df.reset_index().set_index('industry_2')[['industry_1']]
+            _df = _df[~_df.index.duplicated(keep='first')]
+            indus_size_2 = indus_size_2.join(_df)
+            data = {
+                '股票收益':stock_df,
+                '行业一级收益':indus_size_1,
+                '行业二级收益':indus_size_2,
+            }
+            return data
+        except Exception as e:
+            print(f'failed to get data <err_msg> {e} from derived.get_industry_stock_ret_and_size')
+            return False
+
+
     def stock_debt_val_detail(self, index_id, valuation_type,debt_ret_index):
         try:
             dic = {
