@@ -1432,18 +1432,37 @@ class PortfolioDataApi(metaclass=Singleton):
             if not _df2.empty > 0:
                 _df2 = _df2.pivot_table(index='datetime',columns='fof_id',values='adjusted_nav')
                 if not _df1.empty:
-                    _df = _df1.append(_df2).drop_duplicates()
+                    _df = _df1.append(_df2)
+                    res = []
+                    for fund_id in _df2:
+                        if fund_id in _df1:
+                            b_d = _df1[fund_id].dropna().index[0]
+                            e_d = _df1[fund_id].dropna().index[-1]
+                            df_part1 = _df2[[fund_id]].loc[:b_d]
+                            df_part2 = _df2[[fund_id]].loc[e_d:]
+                            _res = [_df1[[fund_id]],df_part1,df_part2]
+                            _res = [i for i in _res if not i.empty]
+                            _df = pd.concat(_res).sort_index()
+                            _df = _df[~_df.index.duplicated(keep='first')]
+                            res.append(_df)
+                        else:
+                            res.append(_df2[[fund_id]])
+                    res_tmp = [_df1[[fund_id]] for fund_id in _df1 if fund_id not in _df2]
+                    res = res+res_tmp
+                    res = [i.dropna() for i in res]
+                    _df = pd.concat(res,axis=1).sort_index()
                 else:
                     _df = _df2.copy()
             else:
-                _df = _df1.copy()
+                _df = _df1.copy()            
             if not _df.empty > 0:
                 result.append(_df)
             _df = basic.get_index_price_dt(index_list=real_ids,start_date=begin_date,end_date=end_date)
             if not _df.empty > 0:
                 _df = _df.pivot_table(index='datetime',columns='index_id',values='close')
                 result.append(_df)
-            df_result = pd.concat(result,axis=1).sort_index()
+            df_result = pd.concat(result,axis=1).sort_index().dropna(how='all',axis=1)
+            df_result = df_result.dropna(axis=0,how='all')
             dic = {
                 'df_result':df_result, 
                 'name_dic':name_dic,
@@ -1561,7 +1580,7 @@ class PortfolioDataApi(metaclass=Singleton):
             if manager_id == None:
                 hf_info = basic.get_fof_info_strategy_exsit(fof_id_list=product_list,manager_id='1')
             else:
-                hf_info = basic.get_fof_info_strategy_exsit(fof_id_list=product_list,manager_id=manager_id)
+                hf_info = basic.get_fof_info_ignore_other_info(fof_id_list=product_list,manager_id=manager_id)
 
             name_dic = hf_info.set_index('fof_id')['fof_name'].to_dict()
             asset_info = basic.get_asset_info_real(real_id_list=product_list)
@@ -1572,23 +1591,39 @@ class PortfolioDataApi(metaclass=Singleton):
                     name_dic[k] = v
             result = []
             real_ids = product_list
-            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20091231')
+            _df1 = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20090101')
             if not _df1.empty > 0:
                 _df1 = _df1.pivot_table(index='datetime',columns='fund_id',values='nav')
             _df2 = derived.get_fof_nav(manager_id=manager_id, fof_id_list=real_ids)
             if not _df2.empty > 0:
                 _df2 = _df2.pivot_table(index='datetime',columns='fof_id',values='adjusted_nav')
                 if not _df1.empty:
-                    _df = _df1.append(_df2).drop_duplicates()
+                    _df = _df1.append(_df2)
+                    res = []
+                    for fund_id in _df2:
+                        if fund_id in _df1:
+                            b_d = _df1[fund_id].dropna().index[0]
+                            e_d = _df1[fund_id].dropna().index[-1]
+                            df_part1 = _df2[[fund_id]].loc[:b_d]
+                            df_part2 = _df2[[fund_id]].loc[e_d:]
+                            _res = [_df1[[fund_id]],df_part1,df_part2]
+                            _res = [i for i in _res if not i.empty]
+                            _df = pd.concat(_res).sort_index()
+                            _df = _df[~_df.index.duplicated(keep='first')]
+                            res.append(_df)
+                        else:
+                            res.append(_df2[[fund_id]])
+                    res_tmp = [_df1[[fund_id]] for fund_id in _df1 if fund_id not in _df2]
+                    res = res+res_tmp
+                    res = [i.dropna() for i in res]
+                    _df = pd.concat(res,axis=1).sort_index()
                 else:
                     _df = _df2.copy()
             else:
-                _df = _df1.copy()
-            if not _df.empty > 0:
-                result.append(_df)
+                _df = _df1.copy() 
             data_dic = {
                 'name_dic':name_dic,
-                'result':result,
+                'result':_df,
             }
             return data_dic
         except Exception as e:
@@ -1605,7 +1640,7 @@ class PortfolioDataApi(metaclass=Singleton):
             if not _df.empty > 0:
                 _df = _df.pivot_table(index='datetime',columns='index_id',values='close')
                 result.append(_df)
-            index_price = pd.concat(result,axis=1).sort_index().ffill().dropna()
+            index_price = pd.concat(result,axis=1).sort_index().ffill()
             if weekly:
                 # 周度
                 index_price_w = basic.data_resample_monthly_nav(index_price,rule='1W').bfill()
@@ -1616,8 +1651,8 @@ class PortfolioDataApi(metaclass=Singleton):
                 if year is None:
                     # 年度
                     index_price_y = basic.data_resample_monthly_nav(index_price.bfill(),rule='Y')
-                    _df = index_price.iloc[[0]]
-                    index_price_y = index_price_y.append(_df).sort_index().drop_duplicates()
+                    _df = index_price.bfill().iloc[[0]]
+                    index_price_y = index_price_y.append(_df).sort_index().drop_duplicates().bfill()
                     index_ret_year = index_price_y.pct_change(1).dropna()
                     td = index_ret_year.index
                     td = [str(i.year) for i in td]
