@@ -3,13 +3,14 @@ from surfing.data.api.raw import *
 from surfing.data.api.basic import *
 from surfing.data.api.derived import *
 from surfing.data.view.TL_models import *
-from surfing.data.wrapper.mysql import TLDatabaseConnector
+from surfing.data.wrapper.mysql import TLDatabaseConnector, TestDatabaseConnector
+from surfing.data.view.test_models import *
 class ResearchApi(metaclass=Singleton):
     
     def get_index_quote(self,start_date,end_date, index_ids):
         """指数行情查询接口"""
-        with BasicDatabaseConnector().managed_session() as db_session:
-            try:
+        try:
+            with BasicDatabaseConnector().managed_session() as db_session:
                 rename_dic = {
                     'total_turnover': 'amount',
                 }
@@ -27,20 +28,44 @@ class ResearchApi(metaclass=Singleton):
                         IndexPrice.index_id.in_(index_ids),
                         IndexPrice.datetime >= start_date, #根据日期筛选数据
                         IndexPrice.datetime <= end_date
+                    )           
+                df1 = pd.read_sql(query.statement, query.session.bind).rename(columns=rename_dic)
+                
+            with RawDatabaseConnector().managed_session() as db_session:
+                rename_dic = {
+                    'index_date':'datetime',
+                }
+                query = db_session.query(
+                        HFIndexPrice.index_id,
+                        HFIndexPrice.index_date,
+                        HFIndexPrice.close
+                    ).filter(
+                        HFIndexPrice.index_id.in_(index_ids),
+                        HFIndexPrice.index_date >= start_date, #根据日期筛选数据
+                        HFIndexPrice.index_date <= end_date
                     )
-                                    
-                df = pd.read_sql(query.statement, query.session.bind).rename(columns=rename_dic)
-                return df
-            except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e) + ' from BasicDataApi.get_index_price')
-                return None
+                df2 = pd.read_sql(query.statement, query.session.bind).rename(columns=rename_dic) 
+                
+            with TestDatabaseConnector().managed_session() as db_session:
+                query = db_session.query(
+                        PfIndexPrice.index_id,
+                        PfIndexPrice.datetime,
+                        PfIndexPrice.close
+                    ).filter(
+                        PfIndexPrice.index_id.in_(index_ids),
+                        PfIndexPrice.datetime >= start_date, #根据日期筛选数据
+                        PfIndexPrice.datetime <= end_date
+                    )
+                df3 = pd.read_sql(query.statement, query.session.bind).rename(columns=rename_dic) 
+            df = pd.concat([df1, df2, df3])
+            return df
+        except Exception as e:
+            print('Failed to get data <err_msg> {}'.format(e) + ' from BasicDataApi.get_index_price')
+            return None
             
     def get_index_info(self, desc_name:list=[]):
-        '''指数基本信息查询接口'''
+        '''指数基本信息模糊查询接口'''
         try:
-            rename_dic = {
-                    'datetime': 'component_date',
-                }
             with BasicDatabaseConnector().managed_session() as db_session:
                 query = db_session.query(
                             IndexInfo.index_id,
@@ -51,31 +76,98 @@ class ResearchApi(metaclass=Singleton):
                     query = query.filter(
                             IndexInfo.desc_name.like(f'%{name_i}%')
                         )
-                df = pd.read_sql(query.statement, query.session.bind)
-                
-            with RawDatabaseConnector().managed_session() as db_session:
-                latest = db_session.query(
-                        func.max(EmIndexComponent.datetime)
-                    ).filter(
-                        EmIndexComponent.em_id.in_(df.em_id),
-                ).one_or_none()[0]
+                df1 = pd.read_sql(query.statement, query.session.bind)
+                dic = {
+                    'real_id':'index_id',
+                    'real_name':'desc_name',
+                    'asset_id':'em_id',
+                }
                 query = db_session.query(
-                            EmIndexComponent.index_id,
-                            EmIndexComponent.stock_list,
-                            EmIndexComponent.datetime,
-                        ).filter(
-                            EmIndexComponent.datetime == latest,
-                            EmIndexComponent.em_id.in_(df.em_id),
+                            AssetInfo.asset_id,
+                            AssetInfo.real_name,
+                            AssetInfo.real_id,
+                )
+                for name_i in desc_name:
+                    query = query.filter(
+                            AssetInfo.real_name.like(f'%{name_i}%')
                         )
                 df2 = pd.read_sql(query.statement, query.session.bind)
-                df = df.drop(labels=['em_id'], axis=1)
-                df = df.set_index('index_id').join(df2.set_index('index_id'))
-                df = df.reset_index().rename(columns=rename_dic)
+                df2 = df2.rename(columns=dic)[dic.values()]
+                
+            with TestDatabaseConnector().managed_session() as db_session:
+                query = db_session.query(
+                            PfIndexInfo.index_id,
+                            PfIndexInfo.desc_name,       
+                )
+                for name_i in desc_name:
+                    query = query.filter(
+                            PfIndexInfo.desc_name.like(f'%{name_i}%')
+                        )
+                df3 = pd.read_sql(query.statement, query.session.bind)
+                df = pd.concat([df1,df2,df3])
                 return df
                 
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from {ResearchApi.get_index_info}')
-                    
+
+    def get_index_info_by_id(self, index_list:list=[]):
+        '''指数基本信息查询接口'''
+        try:
+            with BasicDatabaseConnector().managed_session() as db_session:
+                query = db_session.query(
+                            IndexInfo.index_id,
+                            IndexInfo.desc_name,
+                            IndexInfo.em_id,
+                        ).filter(
+                            IndexInfo.index_id.in_(index_list)
+                        )
+                df1 = pd.read_sql(query.statement, query.session.bind)
+                dic = {
+                    'real_id':'index_id',
+                    'real_name':'desc_name',
+                    'asset_id':'em_id',
+                }
+                query = db_session.query(
+                            AssetInfo.asset_id,
+                            AssetInfo.real_name,
+                            AssetInfo.real_id,
+                        ).filter(
+                            AssetInfo.real_id.in_(index_list)
+                        )
+                df2 = pd.read_sql(query.statement, query.session.bind)
+                df2 = df2.rename(columns=dic)[dic.values()]
+                
+            with TestDatabaseConnector().managed_session() as db_session:
+                query = db_session.query(
+                            PfIndexInfo.index_id,
+                            PfIndexInfo.desc_name,       
+                        ).filter(
+                            PfIndexInfo.index_id.in_(index_list)
+                        )
+                df3 = pd.read_sql(query.statement, query.session.bind)
+            df = pd.concat([df1,df2,df3])
+            return df
+                
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from {ResearchApi.get_index_info}')
+
+
+    def get_index_component(self,index_id,start_date,end_date):
+        '''指数成分股查询'''
+        with RawDatabaseConnector().managed_session() as db_session:
+            try: 
+                    query = db_session.query(
+                        EmIndexComponent
+                    ).filter(
+                        EmIndexComponent.index_id.in_([index_id]),
+                        EmIndexComponent.datetime <= end_date, 
+                        EmIndexComponent.datetime >= start_date
+                        )
+                    index_stocks = pd.read_sql(query.statement, query.session.bind)
+                    return index_stocks                  
+            except Exception as e:
+                    print(f'Failed to get data <err_msg> {e} from {ResearchApi.get_index_component}')
+
     def get_index_fac(self, start_date, end_date, index_ids:list=[]):
         '''指数衍生数据查询接口'''
         with DerivedDatabaseConnector().managed_session() as db_session:
@@ -361,7 +453,7 @@ class ResearchApi(metaclass=Singleton):
                 _df = pd.read_sql(query.statement, query.session.bind).set_index('datetime')
 
                 res = []
-                for code in df.stock_id:
+                for code in df.stock_id.unique():
                     df_i = df[df.stock_id == code].copy()
                     df_i['ret'] = df_i.post_close.pct_change(1)
                     df_i = df_i.loc[start_date:]
@@ -447,7 +539,7 @@ class ResearchApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from ResearchApi.get_future_info')
 
-    def get_future_quote(self, future_ids, start_date, end_date):
+    def get_future_quote(self, future_ids, start_date=None, end_date=None):
         '''期货行情'''
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -467,7 +559,13 @@ class ResearchApi(metaclass=Singleton):
                         EmFuturePriceDetail.PRECLEAR,
                     ).filter(
                         EmFuturePriceDetail.CODES.in_(future_ids),
+                    )
+                if start_date:
+                    query = query.filter(
                         EmFuturePriceDetail.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
                         EmFuturePriceDetail.DATES <= end_date,
                     )
                 df = pd.read_sql(query.statement, query.session.bind).drop(columns = "_update_time", errors='ignore')
@@ -649,8 +747,8 @@ class ResearchApi(metaclass=Singleton):
                 Pfund.INVEST_CONSULTANT,
                 Pfund.ESTABLISH_DATE,
                 Pfund.MANAGER,
+                Pfund.STATUS,
                 Pfund.SECURITY_ID,
-
             )
             # 按照备案号
             if record_cd:
@@ -721,6 +819,7 @@ class ResearchApi(metaclass=Singleton):
             company_dic = _df.set_index('PARTY_ID')['PARTY_SHORT_NAME'].to_dict()
             df.loc[:,'INVEST_CONSULTANT'] = df.INVEST_CONSULTANT.map(lambda x: company_dic.get(x))
 
+            # 替换基金全名
             _query = db_session.query(
                 MdSecurity.SECURITY_ID,
                 MdSecurity.SEC_SHORT_NAME,
@@ -729,6 +828,15 @@ class ResearchApi(metaclass=Singleton):
             name_dic = _df.set_index('SECURITY_ID')['SEC_SHORT_NAME'].to_dict()
             df.loc[:,'SEC_FULL_NAME'] = df.SECURITY_ID.map(name_dic)
             df = df.drop(columns=['SECURITY_ID'])
+
+            # 替换运作状态
+            _query = db_session.query(
+                SysCode.VALUE_NUM_CD,
+                SysCode.VALUE_NAME_CN,
+            ).filter(SysCode.CODE_TYPE_ID == '40034' )
+            _df = pd.read_sql(_query.statement, _query.session.bind)
+            name_dic = _df.set_index('VALUE_NUM_CD')['VALUE_NAME_CN'].to_dict()
+            df['STATUS'] = df.STATUS.map(name_dic)
             return df
 
     def get_pf_info2(self, record_cd):
@@ -1014,6 +1122,46 @@ class ResearchApi(metaclass=Singleton):
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from {ResearchApi.get_pfund_nav}')
 
+    def get_stock_post_price(self,stock_list,start_date,end_date):
+        '''获取股票后复权股价'''
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmStockPostPrice.CLOSE,
+                    EmStockPostPrice.DATES,
+                    EmStockPostPrice.CODES
+
+                ).filter(
+                    EmStockPostPrice.CODES.in_(stock_list),
+                    EmStockPostPrice.DATES >= start_date,
+                    EmStockPostPrice.DATES <= end_date 
+                    )
+                stock_price = pd.read_sql(query.statement, query.session.bind)
+                return stock_price
+            except Exception as e:
+                    print(f'Failed to get data <err_msg> {e} from {ResearchApi.get_stock_post_price}')
+
+
+    def get_trading_date(self, asset_type='cn_stock', start_date=None, end_date=None):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        TradingDayList
+                    )
+                if start_date:
+                    query = query.filter(
+                        TradingDayList.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        TradingDayList.datetime <= end_date,
+                    )
+                tag_df = pd.read_sql(query.statement, query.session.bind)
+                return tag_df
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {TradingDayList.__tablename__}')
+
+
 if __name__ == '__main__':
     start_date = datetime.date(2019,1,1)
     end_date = datetime.date(2021,2,1)
