@@ -79,3 +79,18 @@ class BasicDataHelper:
         print(f'{table_name} costs {now - self._timer}s')
         self._timer = now
         self._updated_count[table_name] += df.shape[0]
+
+    def _qdii_fund_hold_r(self, r, pos_type):
+        r = r[1]
+        target_dic = {'CODES':r['CODES'],'DATES':r['DATES']}
+        idx = 1
+        for i in range(1,21):
+            if pos_type == r[f'rank{i}_type']:
+                target_dic[f'rank{idx}_stock'] = r[f'rank{i}_stock']
+                target_dic[f'rank{idx}_stock_code'] = r[f'rank{i}_stock_code']
+                target_dic[f'rank{idx}_stockval'] = r[f'rank{i}_stockval']
+                target_dic[f'rank{idx}_stockweight'] = r[f'rank{i}_stockweight']
+                idx += 1
+                if idx == 11:
+                    return target_dic
+        return target_dic
\ No newline at end of file
