@@ -5,6 +5,7 @@ import pandas as pd
 from ....util.aip_calc import *
 from ...manager.manager_fund import *
 from ...struct import AssetTradeParam
+from .derived_data_helper import DerivedDataHelper
 
 
 class AIPProcess:
@@ -105,3 +106,8 @@ class AIPProcess:
         p.close()
         p.join()
         self.result = pd.DataFrame(res)
+
+
+if __name__ == '__main__':
+    aipp = AIPProcess(DerivedDataHelper())
+    aipp.process('20210601', '20210601')
