@@ -24,9 +24,12 @@ class FundIndustryExposureProcess:
         self._end_date: str = end_date
 
         # 计算过去离目前最近的数据公布日期
-        real_date = RawDataHelper.get_prev_target_date(end_date, SEMI_UPDATE_DATE_LIST)
+        real_date, aux_date = RawDataHelper.get_prev_and_aux_target_dates(end_date, SEMI_UPDATE_DATE_LIST)
         # 基金的股票持仓明细
-        self._fund_stock_portfolio = BasicDataApi().get_fund_stock_portfolio(dt=real_date).drop(columns=['datetime', '_update_time'])
+        fund_stock_portfolio = BasicDataApi().get_fund_stock_portfolio(dt=real_date).drop(columns=['datetime', '_update_time'])
+        fund_stock_portfolio_aux = BasicDataApi().get_fund_stock_portfolio(dt=aux_date).drop(columns=['datetime', '_update_time'])
+        fund_stock_portfolio_aux = fund_stock_portfolio_aux[~fund_stock_portfolio_aux.fund_id.isin(set(fund_stock_portfolio.fund_id.array))]
+        self._fund_stock_portfolio = pd.concat([fund_stock_portfolio, fund_stock_portfolio_aux])
         stock_list: List[str] = list(self._fund_stock_portfolio.stock_id.unique())
         # 获取涉及到的这些股票的信息
         stock_infos = RawDataApi().get_em_stock_info(stock_list=stock_list)
@@ -77,6 +80,6 @@ class FundIndustryExposureProcess:
 
 
 if __name__ == '__main__':
-    date = '20201106'
+    date = '20201231'
     fsg = FundIndustryExposureProcess(DerivedDataHelper())
     fsg.process(date, date, pd.to_datetime(date).date())
