@@ -374,7 +374,7 @@ class FundIndicatorProcessorGroup:
         fund_result.update({'stock_cl_alpha~history_w':stock_cl_alpha})
         fund_result.update({'stock_cl_beta~history_w':stock_cl_beta})
         _t1 = time.time()
-        print(f'{fund_id} {idx} / {len(self.fund_list)} cost time {_t1 - _t0}')
+        #print(f'{fund_id} {idx} / {len(self.fund_list)} cost time {_t1 - _t0}')
         return fund_result
 
     def calc_indicator(self):
@@ -509,4 +509,17 @@ class FundIndicatorProcessorGroup:
         _s3_bucket_uri: str = f's3://{bucket_name}/dm'
         name = 'fund_indicator_score'
         self.fund_indicator_score.to_parquet(f'{_s3_bucket_uri}/{name}.parquet', compression='gzip')
-        
\ No newline at end of file
+        
+    def process(self,end_date):
+        failed_tasks = []
+        try:
+            self.init(end_date=end_date)
+            self.calc_indicator()
+            self.calc_score()
+            self.add_mng_score()
+            self.to_s3()
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            failed_tasks.append('manager_indicator_score')
+        return failed_tasks
\ No newline at end of file
