@@ -37,10 +37,12 @@ class StyleBoxGenerator:
         start_date_dt = datetime.datetime.strptime(start_date, '%Y%m%d').date()
         start_date_2 = datetime.date(start_date_dt.year - 2, start_date_dt.month, start_date_dt.day)
         self.fin_fac = self._raw_api.get_em_stock_fin_fac(start_date=start_date_2, end_date=end_date)
-        self.earnings = self.fin_fac.reset_index().pivot(index='datetime', columns='stock_id', values='income_statement_61')
-        self.book_values = self.fin_fac.reset_index().pivot(index='datetime', columns='stock_id', values='balance_statement_74')
-        self.revenues = self.fin_fac.reset_index().pivot(index='datetime', columns='stock_id', values='income_statement_9')
-        self.cash = self.fin_fac.reset_index().pivot(index='datetime', columns='stock_id', values='cashflow_statement_39')
+        pivoted_table = self.fin_fac.pivot(index='datetime', columns='stock_id', values=['income_statement_61', 'balance_statement_74', 'income_statement_9', 'cashflow_statement_39'])
+        pivoted_table = pivoted_table.ffill()
+        self.earnings = pivoted_table['income_statement_61']
+        self.book_values = pivoted_table['balance_statement_74']
+        self.revenues = pivoted_table['income_statement_9']
+        self.cash = pivoted_table['cashflow_statement_39']
         # 计算所需的数据
         self.earnings_td = self.earnings.iloc[-1].dropna()
         self.bv_td = self.book_values.iloc[-1].dropna()
@@ -190,6 +192,6 @@ class StyleBoxGenerator:
 
 
 if __name__ == "__main__":
-    date = '20201231'
+    date = '20210111'
     sbg = StyleBoxGenerator(DerivedDataHelper())
     sbg.process(date, date)
