@@ -1,7 +1,8 @@
 import numpy as np
 import pandas as pd
+import datetime
 from .raw_data_helper import RawDataHelper
-from ...view.raw_models import OSFundInfo, OSFundNav, OSFundBenchmark, OSStockInfo, OSCorpBondInfo, OSGovtBondInfo, OSComdtyInfo, OSIndexFutureInfo, OSMtgeBondInfo, EmOverseaStockFinFac, OSFundBenchmarks, OSFundNavAdj
+from ...view.raw_models import OSFundInfo, OSFundNav, OSFundBenchmark, OSStockInfo, OSCorpBondInfo, OSGovtBondInfo, OSComdtyInfo, OSIndexFutureInfo, OSMtgeBondInfo, EmOverseaStockFinFac, OSFundBenchmarks, OSFundNavAdj, HFFundNavMiss
 from ...api.raw import RawDataApi
 
 # df.to_sql('em_oversea_stock_fin_fac', RawDatabaseConnector().get_engine(), index=False, if_exists='append')
@@ -356,4 +357,18 @@ class OtherRawDataDownloader:
             return True
         except Exception as e:
             print(e)
-            return False
\ No newline at end of file
+            return False
+
+    def hf_fund_nav_miss(self):
+        try:
+            failed_tasks = []
+            fund_info = RawDataApi().get_hf_fund_info()
+            begin_date = datetime.datetime.today() - datetime.timedelta(days=365)
+            fund_nav = RawDataApi().get_hf_fund_nav_dt(start_date=begin_date)
+            exsited_fund_list = fund_nav.fund_id.unique().tolist()
+            df = fund_info[~fund_info.fund_id.isin(exsited_fund_list)][['fund_id','desc_name']]
+            self._data_helper._upload_raw(df, HFFundNavMiss.__table__.name, to_truncate=True)
+        except Exception as e:
+            print(e)
+            failed_tasks.append(f'hf_fund_nav_miss')
+        return failed_tasks
