@@ -46,6 +46,13 @@ class RawDataDownloader:
             traceback.print_exc()
             failed_tasks.append('oversea fund nav')
 
+        try:
+            failed_tasks.extend(self.other_raw_data_downloader.hf_fund_nav_miss())
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            failed_tasks.append('hf_fund_nav_miss')
+
         if 'em_tradedates' in failed_tasks:
             return failed_tasks
         else:
