@@ -61,6 +61,7 @@ class IndexDailyCollectionProcessor(object):
                     IndexValuationLongTerm.val_score,
                     IndexValuationLongTerm.datetime,
                     IndexValuationLongTerm.est_peg,
+                    IndexValuationLongTerm.liqmv,
                 ).filter(IndexValuationLongTerm.datetime==latest_time)
                 df = pd.read_sql(query.statement, query.session.bind)
                 df = df.set_index('index_id')
@@ -159,6 +160,30 @@ class IndexDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_index_price<err_msg> {}'.format(e))
 
+    def get_index_price_start_end_date(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    IndexPrice.index_id,
+                    IndexPrice.datetime,
+                    IndexPrice.close)
+                df = pd.read_sql(query.statement, query.session.bind)
+                df = df.pivot_table(index='datetime',values='close',columns='index_id')
+                result = []
+                for index_id in df:
+                    _df = df[[index_id]].dropna()
+                    dic = {
+                        'index_id':index_id,
+                        'price_begin_date':_df.index[0],
+                        'price_end_date':_df.index[-1]
+                    }
+                    result.append(dic)
+                df = pd.DataFrame(result).set_index('index_id')
+                return df
+                
+            except Exception as e:
+                print('Failed get_index_price_start_end_date<err_msg> {}'.format(e))
+
     def calc_percentile(self, df):
         def helper(x, temp_df, column):
             temp_df = temp_df[temp_df['index_id'] == x]
