@@ -173,3 +173,7 @@ class ConcBondIpoCollectionProcessor(object):
         if not self.calc():
             failed_tasks.append('collection_conv_bond_ipo')
         return failed_tasks
+
+
+if __name__ == '__main__':
+    ConcBondIpoCollectionProcessor().process()
