@@ -129,6 +129,9 @@ class SynchronizerS3ForDM(S3ETLTool):
             if isinstance(data, pd.DataFrame) or (data is None):
                 # 这里只处理df以外的数据
                 continue
+            if name in ('mng_best_fund', 'mng_index_list'):
+                # 这两个data是在fund_manager_processor_advanced里dump的
+                continue
 
             # 由于df写parquet很方便，因此这里我们做一些类型转换，把类型均转为df
             if isinstance(data, set) or isinstance(data, list):
@@ -323,7 +326,7 @@ class S3RetrieverForDM(S3ETLTool):
             # TODO: 如果这里DB也失败，应该也需要适当的处理
             return pd.read_sql(query.statement, query.session.bind).drop(columns='_update_time', errors='ignore')
 
-    def _retrieve_dts(self, data_tables: FundDataTables) -> List[str]:
+    def retrieve_dts(self, data_tables: FundDataTables, candidates=None) -> List[str]:
         failed_tables: List[str] = []
         for field in dataclasses.fields(data_tables):
             # 这里不处理df以外的数据
@@ -334,13 +337,21 @@ class S3RetrieverForDM(S3ETLTool):
                 continue
             name = field.name
 
+            if candidates and name not in candidates:
+                continue
+
             _t0 = time.time()
             try:
-                data = pd.read_parquet(f'{self._s3_bucket_uri}/{name}.parquet')
-                # if name == 'cs_index_component':
-                #     data['id_cat'] = data.id_cat.transform()
-                # elif name == 'index_info':
-                #     data['price_source'] = data.price_source.transform()
+                if name in ['mng_indicator_score', 'fund_indicator_score']:
+                    _bucket_name = 'tl-fund-dm'
+                    _s3_bucket_uri: str = f's3://{_bucket_name}/dm'
+                    data = pd.read_parquet(f'{_s3_bucket_uri}/{name}.parquet')
+                else:
+                    data = pd.read_parquet(f'{self._s3_bucket_uri}/{name}.parquet')
+                    # if name == 'cs_index_component':
+                    #     data['id_cat'] = data.id_cat.transform()
+                    # elif name == 'index_info':
+                    #     data['price_source'] = data.price_source.transform()
                 data_tables.__dict__[name] = data
             except (FileNotFoundError, PermissionError, Exception) as e:
                 print(f'WARNING!! retrieve df {name} failed (err_msg){e}')
@@ -351,12 +362,12 @@ class S3RetrieverForDM(S3ETLTool):
 
     def _retrieve_all_dts(self, data_tables: FundDataTables) -> List[str]:
         _t0 = time.time()
-        failed_tables: List[str] = self._retrieve_dts(data_tables)
+        failed_tables: List[str] = self.retrieve_dts(data_tables)
         _t1 = time.time()
         print(f'all dts total cost {_t1 - _t0}s (failed_tables){failed_tables}')
         return failed_tables
 
-    def _retrieve_misc(self, dm) -> List[str]:
+    def retrieve_misc(self, dm, candidates=None) -> List[str]:
         failed_tables: List[str] = []
         for field in dataclasses.fields(dm.dts):
             # 这里不处理df以外的数据
@@ -364,6 +375,9 @@ class S3RetrieverForDM(S3ETLTool):
                 continue
             name = field.name
 
+            if candidates and name not in candidates:
+                continue
+
             _t0 = time.time()
             try:
                 # 把我们保存的df转换回原来的类型
@@ -395,7 +409,7 @@ class S3RetrieverForDM(S3ETLTool):
 
     def _retrieve_all_misc(self, dm) -> List[str]:
         _t0 = time.time()
-        failed_tables: List[str] = self._retrieve_misc(dm)
+        failed_tables: List[str] = self.retrieve_misc(dm)
         _t1 = time.time()
         print(f'all misc total cost {_t1 - _t0}s (failed_tables){failed_tables}')
         return failed_tables
