@@ -113,7 +113,7 @@ class FOFNAVReader:
 
                 abnormal_fof_ids = df[~df.fof_id.isin(self._hedge_list.union(self._product_list))]
                 if not abnormal_fof_ids.empty:
-                    raise Exception(f'got unknown fof_ids {abnormal_fof_ids.fof_id.to_list()}')
+                    self._notify_error_event(f'got unknown fof_ids {abnormal_fof_ids.fof_id.to_list()} (dump) (name){name} (file_path){file_path} (manager_id){self._manager_id} (fof_id){self._fof_id}')
                 time.sleep(1)
             except Exception as e:
                 traceback.print_exc()
