@@ -3,7 +3,8 @@ import datetime
 
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum, VARCHAR
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, SMALLINT, DATETIME, MEDIUMTEXT
+from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, SMALLINT, DATETIME, MEDIUMTEXT, BIGINT, SMALLINT, DECIMAL
+from sqlalchemy.sql.selectable import ScalarSelect
 
 from ...constant import SectorType, IndexPriceSource, HoldingAssetType, FundStatus
 
@@ -909,7 +910,7 @@ class FOFInfo(FOFBase):
     min_admin_fee_amt = Column(DOUBLE(asdecimal=False))     # 行政管理费率最小金额
     lock_up_period = Column(TEXT)                           # 锁定期
     stop_loss = Column(TEXT)                                # 预警/止损配置
-    incentive_fee_mode = Column(VARCHAR(31))                # 业绩报酬计提方法
+    incentive_fee_mode = Column(Integer)                    # 业绩报酬计提方法
     incentive_fee_type = Column(VARCHAR(31))                # 业绩报酬计提类型
     incentive_fee_str = Column(VARCHAR(255))                # 业绩报酬提取规则
     incentive_fee_time = Column(TEXT)                       # 业绩报酬提取时点
@@ -999,11 +1000,12 @@ class FOFAssetAllocation(FOFBase):
     amount = Column(DOUBLE(asdecimal=False))                        # 交易金额
     share = Column(DOUBLE(asdecimal=False))                         # 交易份额
     nav = Column(DOUBLE(asdecimal=False))                           # 交易净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))                 # 累计净值
     status = Column(Enum(FundStatus), nullable=False)               # 状态：在途/完成
     confirmed_date = Column(DATE)                                   # 确认日期
     deposited_date = Column(DATE)                                   # 交割日期
     event_type = Column(Integer)                                    # 事件类型
-    water_line = Column(DOUBLE(asdecimal=False))                    # 水位线(累计净值)
+    water_line = Column(DOUBLE(asdecimal=False))                    # 水位线(一般是累计净值; 但整体高水位法下与累计净值可能不同)
     remark = Column(VARCHAR(255))                                   # 备注
 
 
