@@ -1,6 +1,7 @@
+import numpy as np
 from contextlib import contextmanager
 
-from sqlalchemy import create_engine
+from sqlalchemy import create_engine, event
 from sqlalchemy.orm import scoped_session, sessionmaker
 
 from ...util.singleton import Singleton
@@ -113,5 +114,28 @@ class TestDatabaseConnector(metaclass=Singleton):
         finally:
             session.close()
 
+    def get_engine(self):
+        return self.engine
+
+class TLDatabaseConnector(metaclass=Singleton):
+
+    def __init__(self,db_tag=None):
+        db_conn_str = SurfingConfigurator().get_db_settings(db_name='TL').to_conn_str()
+        self.engine = create_engine(db_conn_str, pool_size=20, max_overflow=20, echo_pool=True)
+        self.smaker = sessionmaker(bind=self.engine)
+        self.scoped_smaker = scoped_session(self.smaker)
+        event.listen(self.engine, "before_cursor_execute", self.add_own_encoders)
+
+    def add_own_encoders(self, conn, cursor, query, *args):
+        cursor.connection.encoders[np.int64] = lambda value, encoders: int(value)
+
+    @contextmanager
+    def managed_session(self):
+        session = self.scoped_smaker()
+        try:
+            yield session
+        finally:
+            session.close()
+
     def get_engine(self):
         return self.engine
\ No newline at end of file
