@@ -5,5 +5,5 @@ class Helper:
     def init(self):
         pass
 
-    def setup(self, saa: AssetWeight):
+    def setup(self, saa: AssetWeight=None):
         pass
