@@ -1363,3 +1363,60 @@ class ReportHelper:
         index_df = df1[['index_id']].append(df2[['index_id']])
         df_combine = df_combine.set_index('fund_id').join(desc_df).join(index_df)
         return df_combine
+
+    def bk_trade_history_to_fof_system(self, m, port_name, saa):
+        df = self.get_fund_trade()
+        fund_weights_df = self.fund_weights_history
+        trade_date_list = sorted(df.trade_date.unique().tolist())
+        asset_desc_dic = {
+            'hs300':'沪深300',
+            'csi500':'中证500',
+            'gem':'创业板',
+            'mmf':'货基',
+            'national_debt':'国债',
+            'sp500rmb':'标普',
+            'gold':'黄金',
+        }
+
+        index_id_list = df.index_id.unique().tolist()
+        fund_desc_dic = m.dts.fund_info.set_index('fund_id')['desc_name'].to_dict()
+        fund_index_dic = df[['fund_id','index_id']].drop_duplicates().set_index('fund_id')['index_id']
+        index_desc_dic = m.dts.index_info.set_index('index_id')['desc_name'].to_dict()
+        benchmark_id_info = {asset_desc_dic[index_id]: index_id for index_id in index_id_list}
+
+        trade_history = []
+        for dt in trade_date_list:
+            dic = {
+                'datetime':str(dt),
+                'fund_weight':[],
+            }
+            fund_weight_dic = fund_weights_df[dt]
+            for fund_id, w in fund_weight_dic.items():
+                if round(w,3) == 0:
+                    continue
+                _dic = {
+                    'fund_id':fund_id,
+                    'weight':round(w,3),
+                    'fund_type':asset_desc_dic[fund_index_dic[fund_id]],
+                    'fund_name':fund_desc_dic[fund_id],
+                }
+                dic['fund_weight'].append(_dic)
+            trade_history.append(dic)
+
+        benchmark_list = []
+        for asset_name, index_id in benchmark_id_info.items():
+            dic = {
+                'asset_name':asset_name,
+                'index_name':index_desc_dic[index_id],
+                'index_id':index_id,
+                'weight':saa.__dict__[index_id],
+            }
+            benchmark_list.append(dic)
+        data_result = {
+            'trade_history':trade_history,
+            'benchmark_info':benchmark_list,
+            'portfolio_name':port_name,
+        }
+        with open(f'{port_name}.json','w',encoding='utf-8') as f:
+            f.write(json.dumps(data_result,ensure_ascii=False))
+        return data_result
\ No newline at end of file
