@@ -32,12 +32,12 @@ class DataStore:
         return data
 
     @staticmethod
-    def refresh_dm(score_pre_calc=True,start_time='20050101',end_time=None,print_time=False,use_weekly_monthly_indicators=False,s3_retriever_activation=None):
+    def refresh_dm(score_pre_calc=True,start_time='20110101',end_time=None,score_manager=None,print_time=False,use_weekly_monthly_indicators=False,s3_retriever_activation=None):
         print(f'start load at {datetime.datetime.now()}')
         t1 = time.time()
         if end_time is None:
             end_time = datetime.datetime.now().strftime('%Y%m%d')
-        dm = FundDataManager(start_time=start_time, end_time=end_time, s3_retriever_activation=s3_retriever_activation)
+        dm = FundDataManager(start_time=start_time, end_time=end_time, score_manager=score_manager, s3_retriever_activation=s3_retriever_activation)
         dm.init(score_pre_calc=score_pre_calc, print_time=print_time, use_weekly_monthly_indicators=use_weekly_monthly_indicators)
         DataStore.store(dm, DataStore.DATA_MANAGER_PATH)
         t2 = time.time()
