@@ -1922,20 +1922,22 @@ class MngFundSize(Factor):
         fund_size = FundSize().get()
         fund_manager_info = fund_manager_info.set_index('fund_id')
         manager_name_dict = fund_manager_info.set_index('manager_id').to_dict()['name'] 
-        return manager_name_dict, fund_manager_info, fund_size
+        return manager_name_dict, fund_manager_info, fund_size, fund_info
 
 
     def calc(self):
-        manager_name_dict, fund_manager_info, fund_size = self.fund_manager_size_prepare()
+        manager_name_dict, fund_manager_info, fund_size, fund_info = self.fund_manager_size_prepare()
         fund_manager_list = list(manager_name_dict.keys())
         t0 = time.time()
         loop_paras = []
         for m_id in fund_manager_list:
             for fund_type in Calculator.FUND_CLASSIFIER:
+                if fund_type == 'index':
+                    continue
                 loop_paras.append([m_id, fund_type])
         result = []
         for para_i in loop_paras:
-            df = self.size_calculation(fund_manager_info, fund_size, para_i) 
+            df = self.size_calculation(fund_manager_info, fund_size, para_i, fund_info) 
             result.append(df)
         t1 = time.time()
         print(f'cost time {t1 - t0}')
@@ -1947,7 +1949,9 @@ class MngFundSize(Factor):
             result.append(pd.Series((date_index >= row.start) & (date_index <= row.end), index=date_index))
         return pd.concat(result, axis=1).sum(axis=1)
 
-    def size_calculation(self, fund_manager_info, fund_size, para_i):
+    def size_calculation(self, fund_manager_info, fund_size, para_i, fund_info):
+        fund_info = fund_info[fund_info.structure_type.isin([0,1])]
+        fund_list = fund_info.fund_id.tolist()
         m_id = para_i[0]
         fund_type = para_i[1]
         wind_class_2_list = Calculator.FUND_CLASSIFIER[fund_type]
@@ -1957,7 +1961,7 @@ class MngFundSize(Factor):
             return None
         index_start_date = this_manager_info.start.min()
         index_end_date = this_manager_info.end.max()
-        this_manager_fund_ids = this_manager_info.index.unique().intersection(fund_size.columns).tolist()
+        this_manager_fund_ids = this_manager_info.index.unique().intersection(fund_size.columns).intersection(fund_list).tolist()
         if len(this_manager_fund_ids) < 1:
             return None
         fund_size = fund_size.loc[index_start_date:index_end_date, this_manager_fund_ids]
