@@ -100,8 +100,8 @@ class MngScoreV1(Factor):
     def score_mng_stock(self, df):
         df.loc[:,'mng_ret_ability'] = score_rescale(0.4 * score_rescale(df['MngAnnualRetDailyHistory']) +0.6 * score_rescale(df['MngTotalRetDailyHistory']))
         df.loc[:,'mng_risk_ability'] = score_rescale(0.3 * score_rescale(-df['MngMddDailyHistory']) + 0.4 * score_rescale(-df['MngAnnualVolDailyHistory']) + 0.3 * score_rescale(-df['MngDownsideStdDailyHistory']))
-        df.loc[:,'mng_select_time'] =  score_rescale(normalize(df['MngClAlphaWeeklyHistory']))
-        df.loc[:,'mng_select_stock'] = score_rescale(normalize(df['MngClBetaWeeklyHistory']) )
+        df.loc[:,'mng_select_stock'] =  score_rescale(normalize(df['MngClAlphaWeeklyHistory']))
+        df.loc[:,'mng_select_time'] = score_rescale(normalize(df['MngClBetaWeeklyHistory']) )
         df.loc[:,'mng_experience'] = score_rescale( 0.8 *  score_rescale(df['MngFundTypeTradingDays']) + 0.2 * score_rescale(df['MngFundSize']))
         df.loc[:,'mng_score'] = score_rescale(df.loc[:,'mng_ret_ability'] + df.loc[:,'mng_risk_ability'] + df.loc[:,'mng_select_time'] + df.loc[:,'mng_select_stock'] + 1.5 * df.loc[:,'mng_experience'])
         return df[['mng_id','mng_ret_ability','mng_risk_ability','mng_select_time','mng_select_stock','mng_experience','mng_score']]
@@ -109,8 +109,8 @@ class MngScoreV1(Factor):
     def score_mng_bond(self, df):
         df.loc[:,'mng_ret_ability'] = score_rescale( 0.8 * score_rescale(df['MngAnnualRetDailyHistory']) + 0.2 * score_rescale(df['MngTotalRetDailyHistory']))
         df.loc[:,'mng_risk_ability'] = score_rescale(0.1 * score_rescale(-df['MngMddDailyHistory']) + 0.4 * score_rescale(-df['MngAnnualVolDailyHistory']) + 0.5 * score_rescale(-df['MngDownsideStdDailyHistory']))
-        df.loc[:,'mng_select_time'] =  score_rescale(normalize(df['MngClAlphaWeeklyHistory']))
-        df.loc[:,'mng_select_stock'] = score_rescale(normalize(df['MngClBetaWeeklyHistory']))
+        df.loc[:,'mng_select_stock'] =  score_rescale(normalize(df['MngClAlphaWeeklyHistory']))
+        df.loc[:,'mng_select_time'] = score_rescale(normalize(df['MngClBetaWeeklyHistory']))
         df.loc[:,'mng_experience'] = score_rescale( 0.8 *  score_rescale(df['MngFundTypeTradingDays']) + 0.2 * score_rescale(df['MngFundSize']))
         df.loc[:,'mng_score'] = score_rescale(1.2 * df.loc[:,'mng_ret_ability'] +  df.loc[:,'mng_risk_ability'] + df.loc[:,'mng_select_time'] + df.loc[:,'mng_select_stock'] + 1.5 * df.loc[:,'mng_experience'])
         return df[['mng_id','mng_ret_ability','mng_risk_ability','mng_select_time','mng_select_stock','mng_experience','mng_score']]
@@ -171,6 +171,11 @@ class MngScoreV1(Factor):
         print(_t1 - _t0)
         self._factor = pd.concat(result).dropna(subset=['mng_score'])
         self._factor = self._factor.reset_index()
+        self._factor = self._factor.set_index('datetime')
+        td = self._factor.index.tolist()
+        td = pd.to_datetime(td)
+        td = [i.date() for i in td] 
+        self._factor.index = td
 
     def append_update(self):
         _exsited_factor = self.get()
@@ -217,7 +222,7 @@ class FundMngScoreV1(Factor):
         type_list = ['stock','bond','index','QDII','mmf']
         manager_score = {}
         for type_i in type_list:
-            _df = total_score[total_score['fund_type'] == type_i].reset_index()#.rename(columns={'index':'datetime'})
+            _df = total_score[total_score['fund_type'] == type_i].reset_index().rename(columns={'index':'datetime'})
             _df = _df.pivot_table(index='datetime',columns='mng_id',values='mng_score')
             manager_score[type_i] = _df
         date_index = manager_score['stock'].index
