@@ -1,8 +1,10 @@
 
+from typing import Dict
+
 import numpy as np
 import pandas as pd
 
-from .factor_types import ValueFactor
+from .factor_types import ValueFactor, MixFactorBase
 from .basic_factors import MarketValueFactor, AdjNetAssetAvgFactor, NetProfitTTMFactor, TotalRevenueTTMFactor
 from .basic_factors import EBITDATTMFactor, EntValueFactor, DividendYearlyFactor
 from .utils import normalize
@@ -12,6 +14,8 @@ class NAToMVFactor(ValueFactor):
     # 净市率
     def __init__(self):
         super().__init__('na_mv')
+        self._deps.add(AdjNetAssetAvgFactor())
+        self._deps.add(MarketValueFactor())
 
     def calc(self):
         # 净资产 / 总市值，即市净率倒数
@@ -22,6 +26,8 @@ class NPToMVFactor(ValueFactor):
     # 盈利收益比
     def __init__(self):
         super().__init__('np_mv')
+        self._deps.add(NetProfitTTMFactor())
+        self._deps.add(MarketValueFactor())
 
     def calc(self):
         # 净利润 / 总市值，即市盈率倒数
@@ -32,6 +38,8 @@ class SPSToPFactor(ValueFactor):
     # 营收股价比
     def __init__(self):
         super().__init__('sps_p')
+        self._deps.add(TotalRevenueTTMFactor())
+        self._deps.add(MarketValueFactor())
 
     def calc(self):
         # 每股销售额 / 股价，即市销率倒数
@@ -42,6 +50,8 @@ class DividendYieldFactor(ValueFactor):
     # 股息率
     def __init__(self):
         super().__init__('dys')
+        self._deps.add(DividendYearlyFactor())
+        self._deps.add(MarketValueFactor())
 
     def calc(self):
         # 过去12个月总派息额 / 总市值
@@ -52,6 +62,8 @@ class EBITDAToMVFactor(ValueFactor):
     # EBITDA股价比
     def __init__(self):
         super().__init__('eb_mv')
+        self._deps.add(EBITDATTMFactor())
+        self._deps.add(MarketValueFactor())
 
     def calc(self):
         # EBITDA（税息折旧及摊销前利润） / 总市值
@@ -62,24 +74,28 @@ class EBITDAToEVFactor(ValueFactor):
     # EBITDA企业价值比
     def __init__(self):
         super().__init__('eb_ev')
+        self._deps.add(EBITDATTMFactor())
+        self._deps.add(EntValueFactor())
 
     def calc(self):
         # EBITDA（税息折旧及摊销前利润） / 企业价值, 即企业倍数的倒数
         self._factor = EBITDATTMFactor().get() / EntValueFactor().get().replace({0: np.nan})
 
 
-class MixValueFactor(ValueFactor):
+class MixValueFactor(MixFactorBase, ValueFactor):
     # 合成因子
     def __init__(self):
-        super().__init__('mixv')
-        self._universe: str = 'default'
+        super(MixFactorBase, self).__init__('mixv')
+        self._factor: Dict[pd.DataFrame] = {}
+        self._deps.add(NAToMVFactor())
+        self._deps.add(NPToMVFactor())
+        self._deps.add(SPSToPFactor())
+        self._deps.add(DividendYieldFactor())
+        self._deps.add(EBITDAToMVFactor())
+        self._deps.add(EBITDAToEVFactor())
 
-    # TODO: 这个接口写的不好，暂时先这样
-    def set_universe(self, universe: str):
-        self._universe = universe
-
-    def calc(self):
-        index = NAToMVFactor().get(self._universe).index
-        columns = NAToMVFactor().get(self._universe).columns
-        self._factor = pd.DataFrame((normalize(NAToMVFactor().get(self._universe).T) + normalize(NPToMVFactor().get(self._universe).T) + normalize(SPSToPFactor().get(self._universe).T) +
-                                    normalize(DividendYieldFactor().get(self._universe).T) + normalize(EBITDAToMVFactor().get(self._universe).T) + normalize(EBITDAToEVFactor().get(self._universe).T)).T, index=index, columns=columns)
+    def calc(self, universe: str):
+        index = NAToMVFactor().get(universe).index
+        columns = NAToMVFactor().get(universe).columns
+        self._factor[universe] = pd.DataFrame((normalize(NAToMVFactor().get(universe).T) + normalize(NPToMVFactor().get(universe).T) + normalize(SPSToPFactor().get(universe).T) +
+                                               normalize(DividendYieldFactor().get(universe).T) + normalize(EBITDAToMVFactor().get(universe).T) + normalize(EBITDAToEVFactor().get(universe).T)).T, index=index, columns=columns)
