@@ -16,10 +16,15 @@ def xnpv(rate, values, dates):
     >>> xnpv(0.1, values, dates)
     -966.4345...
     '''
-    if rate < -0.999999 or math.isclose(rate,-1,rel_tol=1e-09):
+    
+    if rate < -0.999999 or math.isclose(rate,-1,rel_tol=1e-08):
+        return float('inf')
+    try:
+        d0 = min(dates)
+        return sum([ vi / (1.0 + rate)**((di - d0).days / 365.0) for vi, di in zip(values, dates)])
+    except Exception as e:
+        print(f'Failed to calc xnpv rate {rate} values {values} dates {dates} d0 {d0}')
         return float('inf')
-    d0 = dates[0]    # or min(dates)
-    return sum([ vi / (1.0 + rate)**((di - d0).days / 365.0) for vi, di in zip(values, dates)])
 
 def xirr(values, dates):
     '''Equivalent of Excel's XIRR function.
@@ -145,6 +150,7 @@ class AIPCalculator(object):
         self.redeem_date = []
         self.redeem_ret = []
         self.redeem_gain = []
+        self.max_cur_inv_amt = 0
         avg_cost = 0  # 平均投资成本
 
         self.irr_helper = ([], [])
@@ -174,8 +180,12 @@ class AIPCalculator(object):
                     self.tot_inv_amt[-1] += amt_to_trade
                     self.vol[-1] += amt_to_trade * (1 - self.purchase_rate) / p
                     avg_cost = (_tot_cost + amt_to_trade * p) / sum(self.tot_inv_amt)
+                    self.cur_mv[-1] = self.vol[-1] * p
                     self.res.append({'dt': cur_date, 'amt_to_trade': amt_to_trade, 'cur_mv': self.cur_mv[-1],
-                                     'tot_inv_amt': self.tot_inv_amt[-1], 'avg_cost': avg_cost, 'p': p})
+                                     'tot_inv_amt': self.tot_inv_amt[-1], 'avg_cost': avg_cost, 'p': p,
+                                     'cur_gain': sum(self.cur_mv) - sum(self.tot_inv_amt),
+                                     'max_cur_inv_amt': max(self.max_cur_inv_amt, max(self.tot_inv_amt)),
+                                     })
                     last_trade_price = p
                     amt_to_trade = 0
                     # print(f'[{cur_date}] (tot){_tot_cost} (avg){avg_cost} (tot_inv_amt){str(self.tot_inv_amt)}')
