@@ -88,9 +88,16 @@ class MailAttachmentRetriever:
                             if part.get('Content-Disposition') is not None:
                                 filename = part.get_filename()
                                 if filename is not None:
-                                    real_name = email.header.decode_header(filename)[0][0]
+                                    the_header = email.header.decode_header(filename)
+                                    print(f'header length: {len(the_header)}')
+                                    for h in the_header:
+                                        print(f'>> {h}')
+                                    real_name = the_header[0][0]
+                                    print(f'name before decode: {real_name} (type){type(real_name)}')
+                                    print(f'codec: {the_header[0][1]}')
                                     if isinstance(real_name, bytes):
-                                        real_name = real_name.decode(email.header.decode_header(filename)[0][1])
+                                        real_name = real_name.decode(the_header[0][1])
+                                        print(f'name after decode: {real_name}')
                                     dummy_count += 1
                                     for one in self._file_suffixes:
                                         if real_name.endswith(one):
